@@ -1,5 +1,5 @@
 /****************************************************************************
- * Copyright 2018-2023,2024 Thomas E. Dickey                                *
+ * Copyright 2018-2024,2025 Thomas E. Dickey                                *
  * Copyright 1998-2013,2017 Free Software Foundation, Inc.                  *
  *                                                                          *
  * Permission is hereby granted, free of charge, to any person obtaining a  *
@@ -33,7 +33,7 @@
 /*    and: Thomas E. Dickey                        1995-on                  */
 /****************************************************************************/
 
-/* $Id: MKterm.h.awk.in,v 1.87 2024/12/28 21:42:15 tom Exp $ */
+/* $Id: MKterm.h.awk.in,v 1.91 2025/10/18 18:55:31 tom Exp $ */
 
 /*
 **	term.h -- Definition of struct term
@@ -62,7 +62,7 @@ typedef struct screen  SCREEN;
 /* configured with --enable-sp-funcs? */
 #if 1
 #undef  NCURSES_SP_FUNCS
-#define NCURSES_SP_FUNCS 20250329
+#define NCURSES_SP_FUNCS 20251129
 #undef  NCURSES_SP_NAME
 #define NCURSES_SP_NAME(name) name##_sp
 
@@ -84,57 +84,56 @@ typedef int (*NCURSES_SP_OUTC)(SCREEN*, int);
 #define NCURSES_USE_DATABASE 1
 
 #undef  NCURSES_USE_TERMCAP
-#define NCURSES_USE_TERMCAP 0
+#define NCURSES_USE_TERMCAP 1
 
 #undef  NCURSES_XNAMES
 #define NCURSES_XNAMES 1
 
-/* We will use these symbols to hide differences between
+/* TTY, SET_TTY and GET_TTY are used internally */
+#ifdef NCURSES_INTERNALS
+
+/* We use these symbols to hide differences between
  * termios/termio/sgttyb interfaces.
  */
 #undef  TTY
 #undef  SET_TTY
 #undef  GET_TTY
 
-/* Assume POSIX termio if we have the header and function */
-/* #if HAVE_TERMIOS_H && HAVE_TCGETATTR */
-#if 1 && 1
+#if 1 && 1	/* #if HAVE_TERMIOS_H && HAVE_TCGETATTR */
 
 #undef  TERMIOS
 #define TERMIOS 1
-
 #include <termios.h>
 #define TTY struct termios
 
-#else /* !HAVE_TERMIOS_H */
-
-/* #if HAVE_TERMIO_H */
-#if 1
+#elif 1	/* HAVE_TERMIO_H */
 
 #undef  TERMIOS
 #define TERMIOS 1
-
 #include <termio.h>
 #define TTY struct termio
 
-#else /* !HAVE_TERMIO_H */
+#elif (defined(_WIN32) || defined(_WIN64) || defined(__MINGW32__) || defined(__MINGW64__))
+
+struct winconmode
+{
+  unsigned long dwFlagIn;
+  unsigned long dwFlagOut;
+};
 
-#if (defined(_WIN32) || defined(_WIN64))
-/* configured with --enable-exp-win32? */
-#if 0
 #include <win32_curses.h>
 #define TTY struct winconmode
-#else
-#include <ncurses_mingw.h>
-#define TTY struct termios
-#endif
-#else
+
+#elif 1	/* HAVE_SGTTY_H */
+
 #undef TERMIOS
 #include <sgtty.h>
 #include <sys/ioctl.h>
 #define TTY struct sgttyb
-#endif /* MINGW32 */
-#endif /* HAVE_TERMIO_H */
+
+#else
+
+#error no termio/termios/sgtty found
 
 #endif /* HAVE_TERMIOS_H */
 
@@ -142,14 +141,16 @@ typedef int (*NCURSES_SP_OUTC)(SCREEN*, int);
 #define GET_TTY(fd, buf) tcgetattr(fd, buf)
 #define SET_TTY(fd, buf) tcsetattr(fd, TCSADRAIN, buf)
 /* configured with --enable-exp-win32? */
-#elif 0 && (defined(_WIN32) || defined(_WIN64))
+#elif defined(_WIN32) || defined(_WIN64)
 #define GET_TTY(fd, buf) _nc_console_getmode(_nc_console_fd2handle(fd),buf)
 #define SET_TTY(fd, buf) _nc_console_setmode(_nc_console_fd2handle(fd),buf)
-#else
+#elif 1	/* HAVE_SGTTY_H */
 #define GET_TTY(fd, buf) gtty(fd, buf)
 #define SET_TTY(fd, buf) stty(fd, buf)
 #endif
 
+#endif /* NCURSES_INTERNALS */
+
 #ifndef	GCC_NORETURN
 #define	GCC_NORETURN /* nothing */
 #endif
@@ -720,8 +721,28 @@ typedef struct termtype {	/* in-core form of terminfo data */
 #define TERMINAL struct term
 TERMINAL;
 
-#undef TERMTYPE2
-#define TERMTYPE2 TERMTYPE
+/* configured with --enable-ext-colors */
+typedef struct termtype2 {	/* in-core form of terminfo data */
+    char  *term_names;		/* str_table offset of term names */
+    char  *str_table;		/* pointer to string table */
+    NCURSES_SBOOL  *Booleans;	/* array of boolean values */
+    int   *Numbers;		/* array of integer values */
+    char  **Strings;		/* array of string offsets */
+
+#if NCURSES_XNAMES
+    char  *ext_str_table;	/* pointer to extended string table */
+    char  **ext_Names;		/* corresponding names */
+
+    unsigned short num_Booleans;/* count total Booleans */
+    unsigned short num_Numbers;	/* count total Numbers */
+    unsigned short num_Strings;	/* count total Strings */
+
+    unsigned short ext_Booleans;/* count extensions to Booleans */
+    unsigned short ext_Numbers;	/* count extensions to Numbers */
+    unsigned short ext_Strings;	/* count extensions to Strings */
+#endif /* NCURSES_XNAMES */
+
+} TERMTYPE2;
 #else
 
 typedef struct term {		/* describe an actual terminal */
@@ -731,10 +752,10 @@ typedef struct term {		/* describe an actual terminal */
 #endif /* NCURSES_INTERNALS */
 
 /* configured with --enable-broken_linker and reentrancy disabled */
-#if 0 && !0
+#if 0 && !1
 extern NCURSES_EXPORT_VAR(TERMINAL *) cur_term;
 /* reentrancy enabled */
-#elif 0
+#elif 1
 NCURSES_WRAPPED_VAR(TERMINAL *, cur_term);
 #define cur_term   NCURSES_PUBLIC_VAR(cur_term())
 #else
@@ -742,7 +763,7 @@ extern NCURSES_EXPORT_VAR(TERMINAL *) cur_term;
 #endif
 
 /* configured with --enable-broken_linker or reentrancy enabled */
-#if 0 || 0
+#if 0 || 1
 NCURSES_WRAPPED_VAR(NCURSES_CONST char * const *, boolnames);
 NCURSES_WRAPPED_VAR(NCURSES_CONST char * const *, boolcodes);
 NCURSES_WRAPPED_VAR(NCURSES_CONST char * const *, boolfnames);
